from dataclasses import dataclass
from nepali_calendar_utils.data.custom_calendar import CustomCalendar

@dataclass(frozen=True)
class ReferenceDate:
    englishDate: 'CustomCalendar'
    nepaliDate: 'CustomCalendar'

days_in_month_map = {
    1969 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 30, 29, 31],
    1970 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    1971 : [0, 31, 31, 32, 31, 32, 30, 30, 29, 30, 29, 30, 30],
    1972 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    1973 : [0, 30, 32, 31, 32, 31, 30, 30, 30, 29, 30, 29, 31],
    1974 : [0, 30, 32, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    1975 : [0, 31, 31, 32, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    1976 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    1977 : [0, 30, 32, 31, 32, 31, 31, 29, 30, 29, 30, 29, 31],
    1978 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    1979 : [0, 31, 31, 32, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    1980 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    1981 : [0, 31, 31, 31, 32, 31, 31, 29, 30, 30, 29, 30, 30],
    1982 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    1983 : [0, 31, 31, 32, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    1984 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    1985 : [0, 31, 31, 31, 32, 31, 31, 29, 30, 30, 29, 30, 30],
    1986 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    1987 : [0, 31, 32, 31, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    1988 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    1989 : [0, 31, 31, 31, 32, 31, 31, 30, 29, 30, 29, 30, 30],
    1990 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    1991 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 30],
    1992 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 30, 29, 31],
    1993 : [0, 31, 31, 31, 32, 31, 31, 30, 29, 30, 29, 30, 30],
    1994 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    1995 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 30],
    1996 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 30, 29, 31],
    1997 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    1998 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    1999 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2000 : [0, 30, 32, 31, 32, 31, 30, 30, 30, 29, 30, 29, 31],
    2001 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2002 : [0, 31, 31, 32, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    2003 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2004 : [0, 30, 32, 31, 32, 31, 30, 30, 30, 29, 30, 29, 31],
    2005 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2006 : [0, 31, 31, 32, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    2007 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2008 : [0, 31, 31, 31, 32, 31, 31, 29, 30, 30, 29, 29, 31],
    2009 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2010 : [0, 31, 31, 32, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    2011 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2012 : [0, 31, 31, 31, 32, 31, 31, 29, 30, 30, 29, 30, 30],
    2013 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2014 : [0, 31, 31, 32, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    2015 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2016 : [0, 31, 31, 31, 32, 31, 31, 29, 30, 30, 29, 30, 30],
    2017 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2018 : [0, 31, 32, 31, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    2019 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 30, 29, 31],
    2020 : [0, 31, 31, 31, 32, 31, 31, 30, 29, 30, 29, 30, 30],
    2021 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2022 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 30],
    2023 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 30, 29, 31],
    2024 : [0, 31, 31, 31, 32, 31, 31, 30, 29, 30, 29, 30, 30],
    2025 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2026 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2027 : [0, 30, 32, 31, 32, 31, 30, 30, 30, 29, 30, 29, 31],
    2028 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2029 : [0, 31, 31, 32, 31, 32, 30, 30, 29, 30, 29, 30, 30],
    2030 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2031 : [0, 30, 32, 31, 32, 31, 30, 30, 30, 29, 30, 29, 31],
    2032 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2033 : [0, 31, 31, 32, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    2034 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2035 : [0, 30, 32, 31, 32, 31, 31, 29, 30, 30, 29, 29, 31],
    2036 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2037 : [0, 31, 31, 32, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    2038 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2039 : [0, 31, 31, 31, 32, 31, 31, 29, 30, 30, 29, 30, 30],
    2040 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2041 : [0, 31, 31, 32, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    2042 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2043 : [0, 31, 31, 31, 32, 31, 31, 29, 30, 30, 29, 30, 30],
    2044 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2045 : [0, 31, 32, 31, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    2046 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2047 : [0, 31, 31, 31, 32, 31, 31, 30, 29, 30, 29, 30, 30],
    2048 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2049 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 30],
    2050 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 30, 29, 31],
    2051 : [0, 31, 31, 31, 32, 31, 31, 30, 29, 30, 29, 30, 30],
    2052 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2053 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 30],
    2054 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 30, 29, 31],
    2055 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2056 : [0, 31, 31, 32, 31, 32, 30, 30, 29, 30, 29, 30, 30],
    2057 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2058 : [0, 30, 32, 31, 32, 31, 30, 30, 30, 29, 30, 29, 31],
    2059 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2060 : [0, 31, 31, 32, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    2061 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2062 : [0, 30, 32, 31, 32, 31, 31, 29, 30, 29, 30, 29, 31],
    2063 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2064 : [0, 31, 31, 32, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    2065 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2066 : [0, 31, 31, 31, 32, 31, 31, 29, 30, 30, 29, 29, 31],
    2067 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2068 : [0, 31, 31, 32, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    2069 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2070 : [0, 31, 31, 31, 32, 31, 31, 29, 30, 30, 29, 30, 30],
    2071 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2072 : [0, 31, 32, 31, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    2073 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2074 : [0, 31, 31, 31, 32, 31, 31, 30, 29, 30, 29, 30, 30],
    2075 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2076 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 30],
    2077 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 30, 29, 31],
    2078 : [0, 31, 31, 31, 32, 31, 31, 30, 29, 30, 29, 30, 30],
    2079 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2080 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 30],
    2081 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 30, 29, 31],
    2082 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2083 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2084 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2085 : [0, 30, 32, 31, 32, 31, 30, 30, 30, 29, 30, 29, 31],
    2086 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2087 : [0, 31, 31, 32, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    2088 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2089 : [0, 30, 32, 31, 32, 31, 30, 30, 30, 29, 30, 29, 31],
    2090 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2091 : [0, 31, 31, 32, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    2092 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2093 : [0, 31, 31, 31, 32, 31, 31, 29, 30, 30, 29, 29, 31],
    2094 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2095 : [0, 31, 31, 32, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    2096 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31],
    2097 : [0, 31, 31, 31, 32, 31, 31, 29, 30, 30, 29, 30, 30],
    2098 : [0, 31, 31, 32, 31, 31, 31, 30, 29, 30, 29, 30, 30],
    2099 : [0, 31, 31, 32, 32, 31, 30, 30, 29, 30, 29, 30, 30],
    2100 : [0, 31, 32, 31, 32, 31, 30, 30, 30, 29, 29, 30, 31]
}

# For optimization
english_date_map = {
    1914 : ReferenceDate(englishDate = CustomCalendar(year=1914, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1971, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    1915 : ReferenceDate(englishDate = CustomCalendar(year=1915, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1972, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    1916 : ReferenceDate(englishDate = CustomCalendar(year=1916, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1973, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    1917 : ReferenceDate(englishDate = CustomCalendar(year=1917, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=1974, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    1918 : ReferenceDate(englishDate = CustomCalendar(year=1918, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=1975, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    1919 : ReferenceDate(englishDate = CustomCalendar(year=1919, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1976, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    1920 : ReferenceDate(englishDate = CustomCalendar(year=1920, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1977, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    1921 : ReferenceDate(englishDate = CustomCalendar(year=1921, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1978, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    1922 : ReferenceDate(englishDate = CustomCalendar(year=1922, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=103, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=1979, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    1923 : ReferenceDate(englishDate = CustomCalendar(year=1923, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=1980, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    1924 : ReferenceDate(englishDate = CustomCalendar(year=1924, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1981, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    1925 : ReferenceDate(englishDate = CustomCalendar(year=1925, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1982, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    1926 : ReferenceDate(englishDate = CustomCalendar(year=1926, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1983, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    1927 : ReferenceDate(englishDate = CustomCalendar(year=1927, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1984, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    1928 : ReferenceDate(englishDate = CustomCalendar(year=1928, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=1985, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    1929 : ReferenceDate(englishDate = CustomCalendar(year=1929, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=1986, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    1930 : ReferenceDate(englishDate = CustomCalendar(year=1930, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1987, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    1931 : ReferenceDate(englishDate = CustomCalendar(year=1931, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1988, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    1932 : ReferenceDate(englishDate = CustomCalendar(year=1932, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1989, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    1933 : ReferenceDate(englishDate = CustomCalendar(year=1933, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=103, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=1990, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    1934 : ReferenceDate(englishDate = CustomCalendar(year=1934, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=1991, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    1935 : ReferenceDate(englishDate = CustomCalendar(year=1935, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=1992, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    1936 : ReferenceDate(englishDate = CustomCalendar(year=1936, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1993, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    1937 : ReferenceDate(englishDate = CustomCalendar(year=1937, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1994, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    1938 : ReferenceDate(englishDate = CustomCalendar(year=1938, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1995, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    1939 : ReferenceDate(englishDate = CustomCalendar(year=1939, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=103, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=1996, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    1940 : ReferenceDate(englishDate = CustomCalendar(year=1940, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=1997, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    1941 : ReferenceDate(englishDate = CustomCalendar(year=1941, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1998, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    1942 : ReferenceDate(englishDate = CustomCalendar(year=1942, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1999, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    1943 : ReferenceDate(englishDate = CustomCalendar(year=1943, month=4, day_of_month=14, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2000, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    1944 : ReferenceDate(englishDate = CustomCalendar(year=1944, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2001, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    1945 : ReferenceDate(englishDate = CustomCalendar(year=1945, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2002, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    1946 : ReferenceDate(englishDate = CustomCalendar(year=1946, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2003, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    1947 : ReferenceDate(englishDate = CustomCalendar(year=1947, month=4, day_of_month=14, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2004, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    1948 : ReferenceDate(englishDate = CustomCalendar(year=1948, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2005, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    1949 : ReferenceDate(englishDate = CustomCalendar(year=1949, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2006, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    1950 : ReferenceDate(englishDate = CustomCalendar(year=1950, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=103, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2007, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    1951 : ReferenceDate(englishDate = CustomCalendar(year=1951, month=4, day_of_month=14, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2008, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    1952 : ReferenceDate(englishDate = CustomCalendar(year=1952, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2009, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    1953 : ReferenceDate(englishDate = CustomCalendar(year=1953, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2010, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    1954 : ReferenceDate(englishDate = CustomCalendar(year=1954, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2011, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    1955 : ReferenceDate(englishDate = CustomCalendar(year=1955, month=4, day_of_month=14, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2012, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    1956 : ReferenceDate(englishDate = CustomCalendar(year=1956, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2013, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    1957 : ReferenceDate(englishDate = CustomCalendar(year=1957, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2014, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    1958 : ReferenceDate(englishDate = CustomCalendar(year=1958, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2015, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    1959 : ReferenceDate(englishDate = CustomCalendar(year=1959, month=4, day_of_month=14, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2016, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    1960 : ReferenceDate(englishDate = CustomCalendar(year=1960, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2017, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    1961 : ReferenceDate(englishDate = CustomCalendar(year=1961, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=103, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2018, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    1962 : ReferenceDate(englishDate = CustomCalendar(year=1962, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2019, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    1963 : ReferenceDate(englishDate = CustomCalendar(year=1963, month=4, day_of_month=14, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2020, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    1964 : ReferenceDate(englishDate = CustomCalendar(year=1964, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2021, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    1965 : ReferenceDate(englishDate = CustomCalendar(year=1965, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2022, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    1966 : ReferenceDate(englishDate = CustomCalendar(year=1966, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2023, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    1967 : ReferenceDate(englishDate = CustomCalendar(year=1967, month=4, day_of_month=14, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2024, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    1968 : ReferenceDate(englishDate = CustomCalendar(year=1968, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2025, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    1969 : ReferenceDate(englishDate = CustomCalendar(year=1969, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2026, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    1970 : ReferenceDate(englishDate = CustomCalendar(year=1970, month=4, day_of_month=14, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2027, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    1971 : ReferenceDate(englishDate = CustomCalendar(year=1971, month=4, day_of_month=14, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2028, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    1972 : ReferenceDate(englishDate = CustomCalendar(year=1972, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2029, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    1973 : ReferenceDate(englishDate = CustomCalendar(year=1973, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2030, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    1974 : ReferenceDate(englishDate = CustomCalendar(year=1974, month=4, day_of_month=14, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2031, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    1975 : ReferenceDate(englishDate = CustomCalendar(year=1975, month=4, day_of_month=14, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2032, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    1976 : ReferenceDate(englishDate = CustomCalendar(year=1976, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2033, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    1977 : ReferenceDate(englishDate = CustomCalendar(year=1977, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2034, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    1978 : ReferenceDate(englishDate = CustomCalendar(year=1978, month=4, day_of_month=14, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2035, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    1979 : ReferenceDate(englishDate = CustomCalendar(year=1979, month=4, day_of_month=14, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2036, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    1980 : ReferenceDate(englishDate = CustomCalendar(year=1980, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2037, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    1981 : ReferenceDate(englishDate = CustomCalendar(year=1981, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2038, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    1982 : ReferenceDate(englishDate = CustomCalendar(year=1982, month=4, day_of_month=14, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2039, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    1983 : ReferenceDate(englishDate = CustomCalendar(year=1983, month=4, day_of_month=14, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2040, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    1984 : ReferenceDate(englishDate = CustomCalendar(year=1984, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2041, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    1985 : ReferenceDate(englishDate = CustomCalendar(year=1985, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2042, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    1986 : ReferenceDate(englishDate = CustomCalendar(year=1986, month=4, day_of_month=14, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2043, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    1987 : ReferenceDate(englishDate = CustomCalendar(year=1987, month=4, day_of_month=14, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2044, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    1988 : ReferenceDate(englishDate = CustomCalendar(year=1988, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2045, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    1989 : ReferenceDate(englishDate = CustomCalendar(year=1989, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=103, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2046, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    1990 : ReferenceDate(englishDate = CustomCalendar(year=1990, month=4, day_of_month=14, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2047, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    1991 : ReferenceDate(englishDate = CustomCalendar(year=1991, month=4, day_of_month=14, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2048, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    1992 : ReferenceDate(englishDate = CustomCalendar(year=1992, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2049, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    1993 : ReferenceDate(englishDate = CustomCalendar(year=1993, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2050, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    1994 : ReferenceDate(englishDate = CustomCalendar(year=1994, month=4, day_of_month=14, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2051, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    1995 : ReferenceDate(englishDate = CustomCalendar(year=1995, month=4, day_of_month=14, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2052, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    1996 : ReferenceDate(englishDate = CustomCalendar(year=1996, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2053, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    1997 : ReferenceDate(englishDate = CustomCalendar(year=1997, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2054, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    1998 : ReferenceDate(englishDate = CustomCalendar(year=1998, month=4, day_of_month=14, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2055, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    1999 : ReferenceDate(englishDate = CustomCalendar(year=1999, month=4, day_of_month=14, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2056, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2000 : ReferenceDate(englishDate = CustomCalendar(year=2000, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2057, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2001 : ReferenceDate(englishDate = CustomCalendar(year=2001, month=4, day_of_month=14, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2058, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2002 : ReferenceDate(englishDate = CustomCalendar(year=2002, month=4, day_of_month=14, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2059, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2003 : ReferenceDate(englishDate = CustomCalendar(year=2003, month=4, day_of_month=14, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2060, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2004 : ReferenceDate(englishDate = CustomCalendar(year=2004, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2061, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    2005 : ReferenceDate(englishDate = CustomCalendar(year=2005, month=4, day_of_month=14, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2062, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2006 : ReferenceDate(englishDate = CustomCalendar(year=2006, month=4, day_of_month=14, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2063, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2007 : ReferenceDate(englishDate = CustomCalendar(year=2007, month=4, day_of_month=14, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2064, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2008 : ReferenceDate(englishDate = CustomCalendar(year=2008, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2065, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2009 : ReferenceDate(englishDate = CustomCalendar(year=2009, month=4, day_of_month=14, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2066, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    2010 : ReferenceDate(englishDate = CustomCalendar(year=2010, month=4, day_of_month=14, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2067, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2011 : ReferenceDate(englishDate = CustomCalendar(year=2011, month=4, day_of_month=14, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2068, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2012 : ReferenceDate(englishDate = CustomCalendar(year=2012, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2069, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2013 : ReferenceDate(englishDate = CustomCalendar(year=2013, month=4, day_of_month=14, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2070, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2014 : ReferenceDate(englishDate = CustomCalendar(year=2014, month=4, day_of_month=14, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2071, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2015 : ReferenceDate(englishDate = CustomCalendar(year=2015, month=4, day_of_month=14, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2072, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    2016 : ReferenceDate(englishDate = CustomCalendar(year=2016, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2073, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2017 : ReferenceDate(englishDate = CustomCalendar(year=2017, month=4, day_of_month=14, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2074, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2018 : ReferenceDate(englishDate = CustomCalendar(year=2018, month=4, day_of_month=14, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2075, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2019 : ReferenceDate(englishDate = CustomCalendar(year=2019, month=4, day_of_month=14, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2076, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2020 : ReferenceDate(englishDate = CustomCalendar(year=2020, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2077, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2021 : ReferenceDate(englishDate = CustomCalendar(year=2021, month=4, day_of_month=14, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2078, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2022 : ReferenceDate(englishDate = CustomCalendar(year=2022, month=4, day_of_month=14, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2079, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2023 : ReferenceDate(englishDate = CustomCalendar(year=2023, month=4, day_of_month=14, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2080, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2024 : ReferenceDate(englishDate = CustomCalendar(year=2024, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2081, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2025 : ReferenceDate(englishDate = CustomCalendar(year=2025, month=4, day_of_month=14, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2082, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2026 : ReferenceDate(englishDate = CustomCalendar(year=2026, month=4, day_of_month=14, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2083, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    2027 : ReferenceDate(englishDate = CustomCalendar(year=2027, month=4, day_of_month=14, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2084, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2028 : ReferenceDate(englishDate = CustomCalendar(year=2028, month=4, day_of_month=14, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=105, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2085, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2029 : ReferenceDate(englishDate = CustomCalendar(year=2029, month=4, day_of_month=14, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2086, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2030 : ReferenceDate(englishDate = CustomCalendar(year=2030, month=4, day_of_month=14, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2087, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2031 : ReferenceDate(englishDate = CustomCalendar(year=2031, month=4, day_of_month=14, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2088, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2032 : ReferenceDate(englishDate = CustomCalendar(year=2032, month=4, day_of_month=14, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=105, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2089, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2033 : ReferenceDate(englishDate = CustomCalendar(year=2033, month=4, day_of_month=14, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2090, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2034 : ReferenceDate(englishDate = CustomCalendar(year=2034, month=4, day_of_month=14, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2091, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2035 : ReferenceDate(englishDate = CustomCalendar(year=2035, month=4, day_of_month=14, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2092, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2036 : ReferenceDate(englishDate = CustomCalendar(year=2036, month=4, day_of_month=14, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=105, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2093, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2037 : ReferenceDate(englishDate = CustomCalendar(year=2037, month=4, day_of_month=14, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2094, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    2038 : ReferenceDate(englishDate = CustomCalendar(year=2038, month=4, day_of_month=14, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2095, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2039 : ReferenceDate(englishDate = CustomCalendar(year=2039, month=4, day_of_month=14, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2096, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2040 : ReferenceDate(englishDate = CustomCalendar(year=2040, month=4, day_of_month=14, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=105, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2097, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2041 : ReferenceDate(englishDate = CustomCalendar(year=2041, month=4, day_of_month=14, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2098, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2042 : ReferenceDate(englishDate = CustomCalendar(year=2042, month=4, day_of_month=14, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2099, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2043 : ReferenceDate(englishDate = CustomCalendar(year=2043, month=4, day_of_month=14, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2100, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1))
}

nepali_date_map = {
    1971 : ReferenceDate(englishDate = CustomCalendar(year=1914, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1971, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    1972 : ReferenceDate(englishDate = CustomCalendar(year=1915, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1972, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    1973 : ReferenceDate(englishDate = CustomCalendar(year=1916, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1973, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    1974 : ReferenceDate(englishDate = CustomCalendar(year=1917, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=1974, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    1975 : ReferenceDate(englishDate = CustomCalendar(year=1918, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=1975, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    1976 : ReferenceDate(englishDate = CustomCalendar(year=1919, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1976, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    1977 : ReferenceDate(englishDate = CustomCalendar(year=1920, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1977, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    1978 : ReferenceDate(englishDate = CustomCalendar(year=1921, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1978, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    1979 : ReferenceDate(englishDate = CustomCalendar(year=1922, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=103, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=1979, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    1980 : ReferenceDate(englishDate = CustomCalendar(year=1923, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=1980, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    1981 : ReferenceDate(englishDate = CustomCalendar(year=1924, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1981, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    1982 : ReferenceDate(englishDate = CustomCalendar(year=1925, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1982, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    1983 : ReferenceDate(englishDate = CustomCalendar(year=1926, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1983, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    1984 : ReferenceDate(englishDate = CustomCalendar(year=1927, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1984, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    1985 : ReferenceDate(englishDate = CustomCalendar(year=1928, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=1985, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    1986 : ReferenceDate(englishDate = CustomCalendar(year=1929, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=1986, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    1987 : ReferenceDate(englishDate = CustomCalendar(year=1930, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1987, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    1988 : ReferenceDate(englishDate = CustomCalendar(year=1931, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1988, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    1989 : ReferenceDate(englishDate = CustomCalendar(year=1932, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1989, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    1990 : ReferenceDate(englishDate = CustomCalendar(year=1933, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=103, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=1990, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    1991 : ReferenceDate(englishDate = CustomCalendar(year=1934, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=1991, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    1992 : ReferenceDate(englishDate = CustomCalendar(year=1935, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=1992, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    1993 : ReferenceDate(englishDate = CustomCalendar(year=1936, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1993, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    1994 : ReferenceDate(englishDate = CustomCalendar(year=1937, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1994, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    1995 : ReferenceDate(englishDate = CustomCalendar(year=1938, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1995, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    1996 : ReferenceDate(englishDate = CustomCalendar(year=1939, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=103, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=1996, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    1997 : ReferenceDate(englishDate = CustomCalendar(year=1940, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=1997, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    1998 : ReferenceDate(englishDate = CustomCalendar(year=1941, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1998, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    1999 : ReferenceDate(englishDate = CustomCalendar(year=1942, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=1999, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2000 : ReferenceDate(englishDate = CustomCalendar(year=1943, month=4, day_of_month=14, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2000, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2001 : ReferenceDate(englishDate = CustomCalendar(year=1944, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2001, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2002 : ReferenceDate(englishDate = CustomCalendar(year=1945, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2002, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2003 : ReferenceDate(englishDate = CustomCalendar(year=1946, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2003, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2004 : ReferenceDate(englishDate = CustomCalendar(year=1947, month=4, day_of_month=14, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2004, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2005 : ReferenceDate(englishDate = CustomCalendar(year=1948, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2005, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    2006 : ReferenceDate(englishDate = CustomCalendar(year=1949, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2006, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2007 : ReferenceDate(englishDate = CustomCalendar(year=1950, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=103, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2007, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2008 : ReferenceDate(englishDate = CustomCalendar(year=1951, month=4, day_of_month=14, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2008, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2009 : ReferenceDate(englishDate = CustomCalendar(year=1952, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2009, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2010 : ReferenceDate(englishDate = CustomCalendar(year=1953, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2010, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2011 : ReferenceDate(englishDate = CustomCalendar(year=1954, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2011, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    2012 : ReferenceDate(englishDate = CustomCalendar(year=1955, month=4, day_of_month=14, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2012, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2013 : ReferenceDate(englishDate = CustomCalendar(year=1956, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2013, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2014 : ReferenceDate(englishDate = CustomCalendar(year=1957, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2014, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2015 : ReferenceDate(englishDate = CustomCalendar(year=1958, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2015, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2016 : ReferenceDate(englishDate = CustomCalendar(year=1959, month=4, day_of_month=14, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2016, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    2017 : ReferenceDate(englishDate = CustomCalendar(year=1960, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2017, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2018 : ReferenceDate(englishDate = CustomCalendar(year=1961, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=103, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2018, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2019 : ReferenceDate(englishDate = CustomCalendar(year=1962, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2019, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2020 : ReferenceDate(englishDate = CustomCalendar(year=1963, month=4, day_of_month=14, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2020, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2021 : ReferenceDate(englishDate = CustomCalendar(year=1964, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2021, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2022 : ReferenceDate(englishDate = CustomCalendar(year=1965, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2022, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    2023 : ReferenceDate(englishDate = CustomCalendar(year=1966, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2023, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2024 : ReferenceDate(englishDate = CustomCalendar(year=1967, month=4, day_of_month=14, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2024, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2025 : ReferenceDate(englishDate = CustomCalendar(year=1968, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2025, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2026 : ReferenceDate(englishDate = CustomCalendar(year=1969, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2026, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2027 : ReferenceDate(englishDate = CustomCalendar(year=1970, month=4, day_of_month=14, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2027, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    2028 : ReferenceDate(englishDate = CustomCalendar(year=1971, month=4, day_of_month=14, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2028, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2029 : ReferenceDate(englishDate = CustomCalendar(year=1972, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2029, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2030 : ReferenceDate(englishDate = CustomCalendar(year=1973, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2030, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2031 : ReferenceDate(englishDate = CustomCalendar(year=1974, month=4, day_of_month=14, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2031, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2032 : ReferenceDate(englishDate = CustomCalendar(year=1975, month=4, day_of_month=14, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2032, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2033 : ReferenceDate(englishDate = CustomCalendar(year=1976, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2033, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    2034 : ReferenceDate(englishDate = CustomCalendar(year=1977, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2034, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2035 : ReferenceDate(englishDate = CustomCalendar(year=1978, month=4, day_of_month=14, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2035, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2036 : ReferenceDate(englishDate = CustomCalendar(year=1979, month=4, day_of_month=14, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2036, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2037 : ReferenceDate(englishDate = CustomCalendar(year=1980, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2037, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2038 : ReferenceDate(englishDate = CustomCalendar(year=1981, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2038, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2039 : ReferenceDate(englishDate = CustomCalendar(year=1982, month=4, day_of_month=14, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2039, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2040 : ReferenceDate(englishDate = CustomCalendar(year=1983, month=4, day_of_month=14, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2040, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2041 : ReferenceDate(englishDate = CustomCalendar(year=1984, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2041, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2042 : ReferenceDate(englishDate = CustomCalendar(year=1985, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=103, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2042, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2043 : ReferenceDate(englishDate = CustomCalendar(year=1986, month=4, day_of_month=14, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2043, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2044 : ReferenceDate(englishDate = CustomCalendar(year=1987, month=4, day_of_month=14, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2044, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    2045 : ReferenceDate(englishDate = CustomCalendar(year=1988, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2045, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2046 : ReferenceDate(englishDate = CustomCalendar(year=1989, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=103, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2046, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2047 : ReferenceDate(englishDate = CustomCalendar(year=1990, month=4, day_of_month=14, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2047, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2048 : ReferenceDate(englishDate = CustomCalendar(year=1991, month=4, day_of_month=14, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2048, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2049 : ReferenceDate(englishDate = CustomCalendar(year=1992, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2049, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2050 : ReferenceDate(englishDate = CustomCalendar(year=1993, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2050, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    2051 : ReferenceDate(englishDate = CustomCalendar(year=1994, month=4, day_of_month=14, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2051, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2052 : ReferenceDate(englishDate = CustomCalendar(year=1995, month=4, day_of_month=14, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2052, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2053 : ReferenceDate(englishDate = CustomCalendar(year=1996, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2053, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2054 : ReferenceDate(englishDate = CustomCalendar(year=1997, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=103, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2054, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2055 : ReferenceDate(englishDate = CustomCalendar(year=1998, month=4, day_of_month=14, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2055, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    2056 : ReferenceDate(englishDate = CustomCalendar(year=1999, month=4, day_of_month=14, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2056, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2057 : ReferenceDate(englishDate = CustomCalendar(year=2000, month=4, day_of_month=13, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2057, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2058 : ReferenceDate(englishDate = CustomCalendar(year=2001, month=4, day_of_month=14, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2058, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2059 : ReferenceDate(englishDate = CustomCalendar(year=2002, month=4, day_of_month=14, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2059, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2060 : ReferenceDate(englishDate = CustomCalendar(year=2003, month=4, day_of_month=14, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2060, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2061 : ReferenceDate(englishDate = CustomCalendar(year=2004, month=4, day_of_month=13, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2061, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    2062 : ReferenceDate(englishDate = CustomCalendar(year=2005, month=4, day_of_month=14, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2062, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2063 : ReferenceDate(englishDate = CustomCalendar(year=2006, month=4, day_of_month=14, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2063, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2064 : ReferenceDate(englishDate = CustomCalendar(year=2007, month=4, day_of_month=14, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2064, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2065 : ReferenceDate(englishDate = CustomCalendar(year=2008, month=4, day_of_month=13, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2065, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2066 : ReferenceDate(englishDate = CustomCalendar(year=2009, month=4, day_of_month=14, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2066, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    2067 : ReferenceDate(englishDate = CustomCalendar(year=2010, month=4, day_of_month=14, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2067, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2068 : ReferenceDate(englishDate = CustomCalendar(year=2011, month=4, day_of_month=14, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2068, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2069 : ReferenceDate(englishDate = CustomCalendar(year=2012, month=4, day_of_month=13, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2069, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2070 : ReferenceDate(englishDate = CustomCalendar(year=2013, month=4, day_of_month=14, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2070, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2071 : ReferenceDate(englishDate = CustomCalendar(year=2014, month=4, day_of_month=14, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2071, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2072 : ReferenceDate(englishDate = CustomCalendar(year=2015, month=4, day_of_month=14, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2072, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    2073 : ReferenceDate(englishDate = CustomCalendar(year=2016, month=4, day_of_month=13, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2073, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2074 : ReferenceDate(englishDate = CustomCalendar(year=2017, month=4, day_of_month=14, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2074, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2075 : ReferenceDate(englishDate = CustomCalendar(year=2018, month=4, day_of_month=14, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2075, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2076 : ReferenceDate(englishDate = CustomCalendar(year=2019, month=4, day_of_month=14, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2076, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2077 : ReferenceDate(englishDate = CustomCalendar(year=2020, month=4, day_of_month=13, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2077, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2078 : ReferenceDate(englishDate = CustomCalendar(year=2021, month=4, day_of_month=14, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2078, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2079 : ReferenceDate(englishDate = CustomCalendar(year=2022, month=4, day_of_month=14, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2079, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2080 : ReferenceDate(englishDate = CustomCalendar(year=2023, month=4, day_of_month=14, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2080, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2081 : ReferenceDate(englishDate = CustomCalendar(year=2024, month=4, day_of_month=13, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2081, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2082 : ReferenceDate(englishDate = CustomCalendar(year=2025, month=4, day_of_month=14, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2082, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2083 : ReferenceDate(englishDate = CustomCalendar(year=2026, month=4, day_of_month=14, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2083, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    2084 : ReferenceDate(englishDate = CustomCalendar(year=2027, month=4, day_of_month=14, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2084, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2085 : ReferenceDate(englishDate = CustomCalendar(year=2028, month=4, day_of_month=14, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=105, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2085, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2086 : ReferenceDate(englishDate = CustomCalendar(year=2029, month=4, day_of_month=14, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2086, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2087 : ReferenceDate(englishDate = CustomCalendar(year=2030, month=4, day_of_month=14, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2087, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2088 : ReferenceDate(englishDate = CustomCalendar(year=2031, month=4, day_of_month=14, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2088, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2089 : ReferenceDate(englishDate = CustomCalendar(year=2032, month=4, day_of_month=14, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=105, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2089, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2090 : ReferenceDate(englishDate = CustomCalendar(year=2033, month=4, day_of_month=14, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2090, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2091 : ReferenceDate(englishDate = CustomCalendar(year=2034, month=4, day_of_month=14, era=1, first_day_of_month=7, last_day_of_month=1, total_days_in_month=30, day_of_week_in_month=2, day_of_week=6, day_of_year=104, week_of_month=3, week_of_year=15), nepaliDate = CustomCalendar(year=2091, month=1, day_of_month=1, era=2, first_day_of_month=6, last_day_of_month=1, total_days_in_month=31, day_of_week_in_month=1, day_of_week=6, day_of_year=1, week_of_month=1, week_of_year=1)),
    2092 : ReferenceDate(englishDate = CustomCalendar(year=2035, month=4, day_of_month=14, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=104, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2092, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2093 : ReferenceDate(englishDate = CustomCalendar(year=2036, month=4, day_of_month=14, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=105, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2093, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2094 : ReferenceDate(englishDate = CustomCalendar(year=2037, month=4, day_of_month=14, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2094, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1)),
    2095 : ReferenceDate(englishDate = CustomCalendar(year=2038, month=4, day_of_month=14, era=1, first_day_of_month=5, last_day_of_month=6, total_days_in_month=30, day_of_week_in_month=2, day_of_week=4, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2095, month=1, day_of_month=1, era=2, first_day_of_month=4, last_day_of_month=6, total_days_in_month=31, day_of_week_in_month=1, day_of_week=4, day_of_year=1, week_of_month=1, week_of_year=1)),
    2096 : ReferenceDate(englishDate = CustomCalendar(year=2039, month=4, day_of_month=14, era=1, first_day_of_month=6, last_day_of_month=7, total_days_in_month=30, day_of_week_in_month=2, day_of_week=5, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2096, month=1, day_of_month=1, era=2, first_day_of_month=5, last_day_of_month=7, total_days_in_month=31, day_of_week_in_month=1, day_of_week=5, day_of_year=1, week_of_month=1, week_of_year=1)),
    2097 : ReferenceDate(englishDate = CustomCalendar(year=2040, month=4, day_of_month=14, era=1, first_day_of_month=1, last_day_of_month=2, total_days_in_month=30, day_of_week_in_month=2, day_of_week=7, day_of_year=105, week_of_month=2, week_of_year=15), nepaliDate = CustomCalendar(year=2097, month=1, day_of_month=1, era=2, first_day_of_month=7, last_day_of_month=2, total_days_in_month=31, day_of_week_in_month=1, day_of_week=7, day_of_year=1, week_of_month=1, week_of_year=1)),
    2098 : ReferenceDate(englishDate = CustomCalendar(year=2041, month=4, day_of_month=14, era=1, first_day_of_month=2, last_day_of_month=3, total_days_in_month=30, day_of_week_in_month=2, day_of_week=1, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2098, month=1, day_of_month=1, era=2, first_day_of_month=1, last_day_of_month=3, total_days_in_month=31, day_of_week_in_month=1, day_of_week=1, day_of_year=1, week_of_month=1, week_of_year=1)),
    2099 : ReferenceDate(englishDate = CustomCalendar(year=2042, month=4, day_of_month=14, era=1, first_day_of_month=3, last_day_of_month=4, total_days_in_month=30, day_of_week_in_month=2, day_of_week=2, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2099, month=1, day_of_month=1, era=2, first_day_of_month=2, last_day_of_month=4, total_days_in_month=31, day_of_week_in_month=1, day_of_week=2, day_of_year=1, week_of_month=1, week_of_year=1)),
    2100 : ReferenceDate(englishDate = CustomCalendar(year=2043, month=4, day_of_month=14, era=1, first_day_of_month=4, last_day_of_month=5, total_days_in_month=30, day_of_week_in_month=2, day_of_week=3, day_of_year=104, week_of_month=3, week_of_year=16), nepaliDate = CustomCalendar(year=2100, month=1, day_of_month=1, era=2, first_day_of_month=3, last_day_of_month=5, total_days_in_month=31, day_of_week_in_month=1, day_of_week=3, day_of_year=1, week_of_month=1, week_of_year=1))
}